@@ -23,9 +23,10 @@ use strict;
 use warnings;
 use autodie;
 
+use Lintian::Deb822Parser qw(read_dpkg_control :constants);
 use Lintian::Relation;
 use Lintian::Tags qw(tag);
-use Lintian::Util qw(read_dpkg_control :constants $PKGNAME_REGEX);
+use Lintian::Util qw($PKGNAME_REGEX);
 
 # From debconf-devel(7), section 'THE TEMPLATES FILE', up to date with debconf
 # version 1.5.24.  Added indices for cdebconf (indicates sort order for
