@@ -49,7 +49,7 @@ my $compat_level = Lintian::Data->new('debhelper/compat-level',qr/=/);
 my $MISC_DEPENDS = Lintian::Relation->new('${misc:Depends}');
 
 sub run {
-    my (undef, undef, $info) = @_;
+    my (undef, undef, $info, undef, $group) = @_;
     my $droot = $info->index_resolved_path('debian/');
     my ($drules, $dh_bd_version, $level);
 
@@ -70,6 +70,7 @@ sub run {
         'python2' => 0,
         'python3' => 0,
         'runit'   => 0,
+        'nodejs'  => 0,
     );
     my %overrides;
 
@@ -270,7 +271,6 @@ sub run {
 
     for my $binpkg (@pkgs) {
         next if $info->binary_package_type($binpkg) ne 'deb';
-        my $breaks = $info->binary_relation($binpkg, 'breaks');
         my $strong = $info->binary_relation($binpkg, 'strong');
         my $all = $info->binary_relation($binpkg, 'all');
 
@@ -280,10 +280,16 @@ sub run {
             tag 'weak-dependency-on-misc-depends', $binpkg
               unless $strong->implies($MISC_DEPENDS);
         }
+    }
 
-        tag 'package-uses-dh-runit-but-lacks-breaks-substvar',$binpkg
+    for my $proc ($group->get_processables('binary')) {
+        my $binpkg = $proc->pkg_name;
+        my $breaks = $info->binary_relation($binpkg, 'breaks');
+        my $strong = $info->binary_relation($binpkg, 'strong');
+        tag 'package-uses-dh-runit-but-lacks-breaks-substvar', $binpkg
           if $seen{'runit'}
           and $strong->implies('runit')
+          and any { m,^etc/sv/, } $proc->info->sorted_index
           and not $breaks->implies('${runit:Breaks}');
     }
 
@@ -343,6 +349,7 @@ sub run {
         $compatnan = 1;
     }
 
+    tag 'debhelper-compat-level', $level if defined($level);
     $level ||= 1;
     if ($level < $compat_level->value('deprecated')) {
         tag 'package-uses-deprecated-debhelper-compat-version', $level;
@@ -556,7 +563,10 @@ sub run {
               sort(keys %python3_depends);
         }
     }
-
+    if ($seen{'nodejs'} and not $overrides{'dh_auto_test'}) {
+        my $path = $info->index_resolved_path('debian/tests/pkg-js/test');
+        tag 'pkg-js-tools-test-is-missing' unless $path;
+    }
     return;
 }
 
