@@ -384,7 +384,8 @@ sub extract_service_file_values {
 sub check_timers {
     my ($info) = @_;
 
-    return if any { m,^/lib/systemd/system/\.timer$, } $info->sorted_index;
+    return
+      if any { m,^lib/systemd/system/[^\/]+\.timer$, } $info->sorted_index;
 
     for my $file ($info->sorted_index) {
         tag 'missing-systemd-timer-for-cron-script', $file
