@@ -38,12 +38,13 @@ use YAML::XS ();
 
 use Lintian::Command qw(safe_qx);
 use Lintian::Data;
+use Lintian::Deb822Parser qw(read_dpkg_control);
 use Lintian::Internal::FrontendUtil qw(split_tag);
 use Lintian::Profile;
 use Lintian::Relation::Version qw(versions_comparator);
 use Lintian::Reporting::ResourceManager;
-use Lintian::Util qw(read_dpkg_control load_state_cache
-  find_backlog copy_dir run_cmd check_path);
+use Lintian::Reporting::Util qw(load_state_cache find_backlog);
+use Lintian::Util qw(copy_dir run_cmd check_path);
 
 my $CONFIG;
 my %OPT;
