@@ -37,7 +37,9 @@ use List::MoreUtils qw(first_index);
 use POSIX qw(strftime);
 
 use Lintian::Command qw(safe_qx);
-use Lintian::Util qw(find_backlog load_state_cache save_state_cache untaint);
+use Lintian::Reporting::Util
+  qw(find_backlog load_state_cache save_state_cache);
+use Lintian::Util qw(untaint);
 
 my (@LINTIAN_CMD, $LINTIAN_VERSION);
 
@@ -47,19 +49,14 @@ my @REQUIRED_PARAMETERS = qw(
   schedule-limit-groups
   state-dir
 );
-my %OPT = (
-    'use-permanent-lab' => 'guess',
-    'lintian-frontend'  => 'lintian',
-);
+my %OPT = ('lintian-frontend'  => 'lintian',);
 my %OPT_HASH = (
     'schedule-chunk-size=i'   => \$OPT{'schedule-chunk-size'},
     'schedule-limit-groups=i' => \$OPT{'schedule-limit-groups'},
     'state-dir=s'             => \$OPT{'state-dir'},
     'lintian-frontend=s'      => \$OPT{'lintian-frontend'},
     'lintian-log-dir=s'       => \$OPT{'lintian-log-dir'},
-    'lintian-lab=s'           => \$OPT{'lintian-lab'},
     'lintian-scratch-space=s' => \$OPT{'lintian-scratch-space'},
-    'use-permanent-lab!'      => \$OPT{'use-permanent-lab'},
     'help|h'                  => \&usage,
 );
 
@@ -90,18 +87,7 @@ sub check_parameters {
     }
     die("The argument for --schedule-limit-groups must be an > 0\n")
       if $OPT{'schedule-limit-groups'} < 1;
-    if ($OPT{'use-permanent-lab'} eq 'guess') {
-        $OPT{'use-permanent-lab'} = 0;
-        $OPT{'use-permanent-lab'} = 1 if $OPT{'lintian-lab'};
-    } elsif ($OPT{'use-permanent-lab'} and not $OPT{'lintian-lab'}) {
-        die(    'If --use-permanent-lab is given, then'
-              . " --lintian-lab must be given too\n");
-    } elsif (not $OPT{'use-permanent-lab'} and $OPT{'lintian-lab'}) {
-        warn(   'Ignoring --lintian-lab when explicit'
-              . " --no-use-permanent-lab is given\n");
-        warn("Perhaps you wanted --lintian-scratch-space <PATH> instead?\n");
-        delete($OPT{'lintian-lab'});
-    }
+
     return;
 }
 
@@ -117,9 +103,7 @@ sub prepare_lintian_environment_and_cmdline {
         "+${logs_dir}/lintian-perf.log",
     );
     $frontend = $OPT{'lintian-frontend'} if ($OPT{'lintian-frontend'});
-    if ($OPT{'use-permanent-lab'}) {
-        push(@args, '--lab', $OPT{'lintian-lab'});
-    }
+
     if ($eoa_marker_index > -1) {
         # Move known "non-parameters" and the "--" behind our arguments.
         # It is a misfeature, but at least it does not break
@@ -213,7 +197,7 @@ sub process_worklist {
     log_msg('Command line used: ' . join(q{ }, @LINTIAN_CMD));
     while (@worklist) {
         my $len = scalar @worklist;
-        my (@work_splice, @completed, %processed);
+        my (@work_splice, @completed, %processed, %errors);
         my ($lintpipe, $lint_stdin, $status_fd, $lint_status_out);
         my $got_alarm = 0;
 
@@ -299,8 +283,10 @@ sub process_worklist {
             my $time_limit
               = $start_time + BACKLOG_PROCESSING_TIME_LIMIT - time();
             my $count = 0;
+            my $signalled_lintian = 0;
             my $sig_handler = sub {
                 my ($signal_name) = @_;
+                $signalled_lintian = 1;
                 $count++;
                 if ($signal_name eq 'ALRM') {
                     $got_alarm = 1 if $got_alarm >= 0;
@@ -345,6 +331,14 @@ sub process_worklist {
                     log_msg("  [lintian] error processing $group_id "
                           . "(time: $runtime)");
                     $processed{$group_id} = 1;
+                    # We ignore errors if we sent lintian a signal to avoid
+                    # *some* false-positives.
+                    $errors{$group_id} = 1 if not $signalled_lintian;
+                } elsif ($line =~ m/^ack-signal (SIG\S+)$/) {
+                    my $signal = $1;
+                    log_msg(
+                        "Signal $signal acknowledged: disabled timed alarms");
+                    alarm(0);
                 }
             }
             alarm(0);
@@ -389,6 +383,7 @@ sub process_worklist {
         } else {
             log_msg('Lintian finished successfully');
         }
+        log_msg('Updating the lintian log used for reporting');
         my $filter = generate_log_filter($state, \%processed);
         seek($nfd, 0, SEEK_END);
         update_lintian_log($filter, $nfd, $new_lintian_log);
@@ -405,6 +400,32 @@ sub process_worklist {
             $group_data = $state->{'groups'}{$group_id};
             $group_data->{'last-processed-by'} = $LINTIAN_VERSION;
             delete($group_data->{'out-of-date'});
+            # Always clear the error counter after a successful run.
+            delete($group_data->{'processing-errors'});
+            delete($group_data->{'last-error-by'});
+        }
+        for my $group_id (sort(keys(%errors))) {
+            my $group_data;
+            # In theory, they can disappear - in practise, that requires
+            # an external call to (e.g.) dplint reporting-sync-state.
+            next if not exists($state->{'groups'}{$group_id});
+            $group_data = $state->{'groups'}{$group_id};
+            if ($errors{$group_id}) {
+                if (not exists($group_data->{'last-error-by'})
+                    or $group_data->{'last-error-by'} ne $LINTIAN_VERSION) {
+                    # If it is a new lintian version then (re)set the counter
+                    # to 1.  Case also triggers for the very first issue.
+                    $group_data->{'processing-errors'} = 1;
+                } else {
+                    # Repeated error with the same version
+                    ++$group_data->{'processing-errors'};
+                }
+                # Set the "last-error-by" flag so we can clear the
+                # error if there is a new version of lintian.
+                $group_data->{'last-error-by'} = $LINTIAN_VERSION;
+            } else {
+                delete($group_data->{'processing-errors'});
+            }
         }
         save_state_cache($OPT{'state-dir'}, $state);
         last if $exit_code;
@@ -441,7 +462,7 @@ sub update_lintian_log {
                 m/^N: [ ] Processing [ ] (binary|udeb|source) [ ]
                        package [ ] (\S+) [ ] \(version [ ] (\S+), [ ]
                        arch [ ] (\S+)\)[ ]\.\.\./oxsm
-              ) {
+            ) {
                 my ($type, $pkg, $ver, $arch) = ($1,$2, $3, $4);
                 my $k = "$type:$pkg/$ver";
                 $k .= "/$arch" if $type ne 'source';
@@ -493,15 +514,11 @@ Usage: $me <args> -- <extra lintian args>
 
   --lintian-frontend PROG     Use PROG as frontend for lintian (defaults to "lintian")
   --lintian-log-dir DIR       Path to the harness log dir. [!]
-  --lintian-lab DIR           Use DIR as permanent lab (implies --use-permanent-lab).
-                              Ignored with --no-use-permanent-lab.
   --lintian-scratch-space DIR Use DIR for temporary files (notably temp labs)
   --schedule-chunk-size N     Run at most N groups in a given lintian run.
   --schedule-limit-groups N   Schedule at most N groups in total. [!]
   --state-dir DIR             Directory containing the state cache (must be
                               writable). [!]
-  --[no-]use-permanent-lab    Whether to use a permanent lab for lintian instead of
-                              throw away labs.
 
 Arguments marked with [!] are required for a successful run.
 EOF
