@@ -27,15 +27,17 @@ use File::Basename qw(basename);
 use YAML::XS ();
 use MIME::Base64 qw(encode_base64);
 
+use Lintian::Deb822Parser qw(visit_dpkg_paragraph);
 use Lintian::Lab;
 use Lintian::Relation::Version qw(versions_comparator);
-use Lintian::Util qw(
+use Lintian::Reporting::Util qw(
   find_backlog
   load_state_cache
-  open_gz
   save_state_cache
+);
+use Lintian::Util qw(
+  open_gz
   strip
-  visit_dpkg_paragraph
 );
 
 my $DEFAULT_CHECKSUM = 'sha256';
