@@ -202,13 +202,27 @@ sub check_maintainer {
                 ($mail eq 'debian-qa@lists.debian.org')
                 or (    $name =~ /\bdebian\s+qa\b/i
                     and $mail ne 'packages@qa.debian.org')
-              ) {
+            ) {
                 tag 'wrong-debian-qa-address-set-as-maintainer',$maintainer;
             } elsif ($mail eq 'packages@qa.debian.org') {
                 tag 'wrong-debian-qa-group-name', $maintainer
                   if ($name ne 'Debian QA Group');
             }
         }
+
+        # Changed-by specific tests.
+        if ($field eq 'changed-by') {
+            my $DERIVATIVE_CHANGED_BY
+              = Lintian::Data->new('common/derivative-changed-by',
+                qr/\s*~~\s*/, sub { $_[1]; });
+
+            foreach my $re ($DERIVATIVE_CHANGED_BY->all) {
+                next if $maintainer =~ m/$re/;
+                my $explanation = $DERIVATIVE_CHANGED_BY->value($re);
+                tag "$field-invalid-for-derivative", $maintainer,
+                  "($explanation)";
+            }
+        }
     }
     return;
 }
@@ -269,6 +283,7 @@ sub check_spelling {
 
     my (%seen, %duplicates, $last_word, $quoted);
     my $counter = 0;
+    my $text_orig = $text;
 
     if (!%CORRECTIONS) {
         my $corrections_multiword
@@ -284,7 +299,9 @@ sub check_spelling {
         }
     }
 
-    $text =~ tr/()[]//d;
+    $text =~ tr/[]//d;
+    # Strip () except for "(s)" suffixes.
+    $text =~ s/(\((?!s\))|(?<!\(s)\))//gi;
     $text =~ s/(\w-)\s*\n\s*/$1/;
     $text =~ tr/\r\n \t/ /s;
     $text =~ s/\s++/ /g;
@@ -302,7 +319,10 @@ sub check_spelling {
         if ($duplicate_check and defined($last_word) and $last_word eq $word) {
             # Avoid flagging words inside quoted text.
             $code_ref->("$word $word (duplicate word)", $word)
-              if not $quoted and not $duplicates{$word}++;
+              if not $quoted
+              and not $duplicates{$word}++
+              and not $ends_with_punct
+              and $text_orig !~ /\b$word\s*\($word\b/;
         }
 
         if ($word =~ m/^[A-Za-z]+$/ and not $ends_with_punct) {
