@@ -27,8 +27,8 @@ Test::Lintian::Helper -- Helper functions for various testing parts
 
 =head1 SYNOPSIS
 
-  use Test::Lintian::Helper qw(get_host_architecture);
-  my $arch = get_host_architecture();
+  use Test::Lintian::Helper qw(get_latest_policy);
+  my $policy_version = get_latest_policy();
 
 =head1 DESCRIPTION
 
@@ -45,40 +45,46 @@ use Exporter qw(import);
 
 BEGIN {
     our @EXPORT_OK = qw(
-      get_host_architecture
+      cache_dpkg_architecture_values
       get_latest_policy
       get_recommended_debhelper_version
       get_required_debhelper_version
-      get_installed_debhelper_version
       copy_dir_contents
       rfc822date
     );
 }
 
+use Capture::Tiny qw(capture);
 use Carp;
 use File::Spec::Functions qw(abs2rel rel2abs);
 use File::Path qw(remove_tree);
 use Path::Tiny;
 use POSIX qw(locale_h strftime);
 
-use Lintian::Command qw(safe_qx);
-use Lintian::Util qw(read_dpkg_control);
 use Lintian::Data;
+use Lintian::Deb822Parser qw(read_dpkg_control);
+use Lintian::Profile;
 
 =head1 FUNCTIONS
 
 =over 4
 
-=item get_host_architecture()
+=item cache_dpkg_architecture_values()
 
-Returns a string containing the value of $DEB_HOST_ARCH.
+Ensures that the output from dpkg-architecture has been cached.
 
 =cut
 
-sub get_host_architecture {
-    my $architecture = safe_qx('dpkg-architecture', '-qDEB_HOST_ARCH');
-    chomp $architecture;
-    return $architecture;
+sub cache_dpkg_architecture_values {
+    open(my $fd, '-|', 'dpkg-architecture')
+      or die('dpkg-architecture failed');
+    while (my $line = <$fd>) {
+        chomp($line);
+        my ($k, $v) = split(/=/, $line, 2);
+        $ENV{$k} = $v;
+    }
+    close($fd);
+    return;
 }
 
 =item get_latest_policy()
@@ -149,22 +155,6 @@ sub get_required_debhelper_version {
     return $version;
 }
 
-=item get_installed_debhelper_version()
-
-Returns the version of debhelper installed on the running system.
-
-=cut
-
-sub get_installed_debhelper_version {
-    die 'Debhelper is not installed.'
-      unless safe_qx('dpkg-query', '--showformat=\${Status}',
-        '--show debhelper') eq 'install ok installed';
-
-    my $version
-      = safe_qx('dpkg-query', '--showformat=\${Version}', '--show debhelper');
-    return $version;
-}
-
 =item copy_dir_contents(SRC_DIR, TARGET_DIR)
 
 Populates TARGET_DIR with files/dirs from SRC_DIR, preserving all attributes but
@@ -223,3 +213,8 @@ sub rfc822date {
 
 1;
 
+# Local Variables:
+# indent-tabs-mode: nil
+# cperl-indent-level: 4
+# End:
+# vim: syntax=perl sw=4 sts=4 sr et
