@@ -67,6 +67,7 @@ use Test::Lintian::Templates
 use constant EMPTY => q{};
 use constant SPACE => q{ };
 use constant COMMA => q{,};
+use constant NEWLINE => qq{\n};
 
 my $EARLY_LOG_SUFFIX = 'log';
 
@@ -86,11 +87,10 @@ sub early_logpath {
     return "$runpath.$EARLY_LOG_SUFFIX";
 }
 
-=item logged_prepare(SPEC_PATH, RUN_PATH, $SUITE, TEST_SET, REBUILD)
+=item logged_prepare(SPEC_PATH, RUN_PATH, TEST_SET, REBUILD)
 
 Prepares the work directory RUN_PATH for the test specified in
-SPEC_PATH. The test is assumed to be part of suite SUITE. The optional
-parameter REBUILD can force a rebuild if true.
+SPEC_PATH. The optional parameter REBUILD forces a rebuild if true.
 
 Captures all output and places it in a file near the work directory.
 The log can be used as a starting point by the runner after copying
@@ -99,7 +99,7 @@ it to a final location.
 =cut
 
 sub logged_prepare {
-    my ($specpath, $runpath, $suite, $testset, $force_rebuild)= @_;
+    my ($specpath, $runpath, $testset, $force_rebuild)= @_;
 
     my $log;
     my $error;
@@ -109,7 +109,7 @@ sub logged_prepare {
 
         try {
             # prepare
-            prepare($specpath, $runpath, $suite, $testset, $force_rebuild);
+            prepare($specpath, $runpath, $testset, $force_rebuild);
         }
         catch {
             # catch any error
@@ -125,24 +125,24 @@ sub logged_prepare {
 
     # print something if there was an error
     if ($error) {
-        print $log if $log;
-        die $error;
+        my $message;
+        $message = NEWLINE . $log if length $log;
+        $message .= $error;
+        die $message;
     }
 
     return;
 }
 
-=item prepare(SPEC_PATH, $RUN_PATH, $SUITE, TEST_SET, REBUILD)
+=item prepare(SPEC_PATH, RUN_PATH, TEST_SET, REBUILD)
 
-Populates a work directory $RUN_PATH with data from the test located
-in SPEC_PATH, which is assumed to belong to suite SUITE.
-
-The optional parameter REBUILD forces a rebuild if true.
+Populates a work directory RUN_PATH with data from the test located
+in SPEC_PATH. The optional parameter REBUILD forces a rebuild if true.
 
 =cut
 
 sub prepare {
-    my ($specpath, $runpath, $suite, $testset, $force_rebuild)= @_;
+    my ($specpath, $runpath, $testset, $force_rebuild)= @_;
 
     say '------- Preparation starts here -------';
     say "Work directory is $runpath.";
@@ -179,9 +179,6 @@ sub prepare {
     # record path to specification
     $testcase->{spec_path} = $specpath;
 
-    # record suite
-    $testcase->{suite} = $suite;
-
     unless ($testcase->{testname} && exists $testcase->{version}) {
         die 'Name or Version missing';
     }
@@ -244,12 +241,16 @@ sub prepare {
         make_path($runpath);
     }
 
+    # delete old test scripts
+    my @oldrunners = File::Find::Rule->file->name('*.t')->in($runpath);
+    unlink(@oldrunners);
+
     # load skeleton
     if (exists $testcase->{skeleton}) {
 
         # the skeleton we are working with
         my $skeletonname = $testcase->{skeleton};
-        my $skeletonpath = "$testset/skeletons/$suite/$skeletonname";
+        my $skeletonpath = "$testset/skeletons/$skeletonname";
 
         my $skeleton = read_config($skeletonpath);
 
@@ -275,7 +276,7 @@ sub prepare {
     copy_dir_contents($specpath, $runpath);
 
     # get builder name
-    my $buildername = $testcase->{builder};
+    my $buildername = $files->{builder};
     if (length $buildername) {
         my $builderpath = "$runpath/$buildername";
 
@@ -324,16 +325,10 @@ sub prepare {
         $testcase, $data_epoch, $runpath, $testset)
       if exists $testcase->{fill_targets};
 
-    # delete previous test scripts
-    my @oldrunners = File::Find::Rule->file->name('*.t')->in($runpath);
-    unlink(@oldrunners);
-
-    # copy test script
-    my $runnerpath = "$testset/runners/$testcase->{runner}";
+    # make sure we installed a runner
+    my $runnerpath = "$runpath/$testcase->{runner}";
     die "No runner found at $runnerpath"
       unless -f $runnerpath;
-    die "Could not install runner: $!"
-      if(system('cp', '-p', $runnerpath, "$runpath/"));
 
     # write the dynamic file names
     my $runfiles = path($runpath)->child('files');
