@@ -62,10 +62,9 @@ use List::Compare;
 use List::Util qw(max min any all);
 use Path::Tiny;
 use Test::More;
-use Text::CSV;
+use Text::Diff;
 use Try::Tiny;
 
-use Lintian::Command qw(safe_qx);
 use Lintian::Profile;
 
 use Test::Lintian::ConfigFile qw(read_config);
@@ -73,8 +72,7 @@ use Test::Lintian::Helper qw(rfc822date);
 use Test::Lintian::Hooks
   qw(find_missing_prerequisites run_lintian sed_hook sort_lines calibrate);
 use Test::Lintian::Prepare qw(early_logpath);
-use Test::Lintian::UniversalTags qw(get_tagnames);
-use Test::StagedFileProducer;
+use Test::Lintian::Output::Universal qw(get_tagnames order);
 
 use constant SPACE => q{ };
 use constant EMPTY => q{};
@@ -82,6 +80,11 @@ use constant NEWLINE => qq{\n};
 use constant YES => q{yes};
 use constant NO => q{no};
 
+# turn off the @@-style headers in Text::Diff
+no warnings 'redefine';
+sub Text::Diff::Unified::file_header { return EMPTY; }
+sub Text::Diff::Unified::hunk_header { return EMPTY; }
+
 =head1 FUNCTIONS
 
 =over 4
@@ -240,172 +243,133 @@ sub runner {
     # set the testing plan
     plan tests => 1;
 
-    my $producer = Test::StagedFileProducer->new(path => $runpath);
-    $producer->exclude(@exclude);
-
     # get lintian subject
     die 'Could not get subject of Lintian examination.'
       unless exists $testcase->{build_product};
     my $subject = "$runpath/$testcase->{build_product}";
 
-    # build subject for lintian examination
-    $producer->add_stage(
-        products => [$subject],
-        minimum_epoch => $threshold,
-        build =>sub {
-            if(exists $testcase->{build_command}) {
-                my $command= "cd $runpath; $testcase->{build_command}";
-                die "$command failed" if system($command);
-            }
-
-            die 'Build was unsuccessful.'
-              unless -f $subject;
-        });
-
     # run lintian
-    my $actual = "$runpath/tags.actual";
-    $producer->add_stage(
-        products => [$actual],
-        minimum_epoch => $lintian_epoch,
-        build =>sub {
-            $ENV{'LINTIAN_COVERAGE'}.= ",-db,./cover_db-$testcase->{testname}"
-              if exists $ENV{'LINTIAN_COVERAGE'};
+    $ENV{'LINTIAN_COVERAGE'}.= ",-db,./cover_db-$testcase->{testname}"
+      if exists $ENV{'LINTIAN_COVERAGE'};
 
-            my $lintian = read_config("$runpath/lintian-command");
-            my $command
-              = "cd $runpath; $ENV{'LINTIAN_FRONTEND'} $lintian->{options} $lintian->{subject}";
-            my ($output, $status) = capture_merged { system($command); };
-            $status = ($status >> 8) & 255;
+    my $lintian = read_config("$runpath/lintian-command");
+    my $command
+      = "cd $runpath; $ENV{'LINTIAN_FRONTEND'} $lintian->{options} $lintian->{subject}";
+    my ($output, $status) = capture_merged { system($command); };
+    $status = ($status >> 8) & 255;
 
-            my @lines = split(NEWLINE, $output);
+    die "$command exited with status $status" . NEWLINE . $output
+      unless $status == 0 || $status == 1;
 
-            if (exists $ENV{LINTIAN_COVERAGE}) {
-                # Devel::Cover causes deep recursion warnings.
-                @lines = grep {
-                    !m{^Deep [ ] recursion [ ] on [ ] subroutine [ ]
-                   "[^"]+" [ ] at [ ] .*B/Deparse.pm [ ] line [ ]
-                   \d+}xsm
-                } @lines;
-            }
+    # filter out some warnings if running under coverage
+    my @lines = split(/\n/, $output);
+    if (exists $ENV{LINTIAN_COVERAGE}) {
+        # Devel::Cover causes deep recursion warnings.
+        @lines = grep {
+            !m{^Deep [ ] recursion [ ] on [ ] subroutine [ ]
+           "[^"]+" [ ] at [ ] .*B/Deparse.pm [ ] line [ ]
+           \d+}xsm
+        } @lines;
+    }
 
-            unless ($status == 0 || $status == 1) {
-                unshift(@lines, "$command exited with status $status");
-                die join(NEWLINE, @lines);
-            }
+    # put output back together
+    $output = EMPTY;
+    $output .= $_ . NEWLINE for @lines;
 
-            # do not forget the final newline, or sorting will fail
-            my $contents
-              = scalar @lines ? join(NEWLINE, @lines) . NEWLINE : EMPTY;
-            path($actual)->spew($contents);
-        });
+    die 'No match strategy defined'
+      unless length $testcase->{match_strategy};
 
-    # run a sed-script if it exists
-    my $parsed = "$runpath/tags.actual.parsed";
-    $producer->add_stage(
-        products => [$parsed],
-        build =>sub {
-            my $script = "$runpath/post_test";
-            if(-f $script) {
-                sed_hook($script, $actual, $parsed);
-            } else {
-                die"Could not copy actual tags $actual to $parsed: $!"
-                  if(system('cp', '-p', $actual, $parsed));
-            }
-        });
-
-    # sort tags
-    my $sorted = "$runpath/tags.actual.parsed.sorted";
-    $producer->add_stage(
-        products => [$sorted],
-        build =>sub {
-            if($testcase->{sort} eq 'yes') {
-                sort_lines($parsed, $sorted);
-            } else {
-                die"Could not copy parsed tags $parsed to $sorted: $!"
-                  if(system('cp', '-p', $parsed, $sorted));
-            }
-        });
-
-    my $specified = "$runpath/tags";
-
-    # calibrate tags; may write to $sorted
-    my $calibrated = "$runpath/tags.specified.calibrated";
-    $producer->add_stage(
-        products => [$calibrated],
-        build =>sub {
-            my $script = "$runpath/test_calibration";
-            if(-x $script) {
-                calibrate($script, $sorted, $specified, $calibrated);
-            } else {
-                die"Could not copy expected tags $specified to $calibrated: $!"
-                  if(system('cp', '-p', $specified, $calibrated));
-            }
-        });
-
-    # extract expected tags
-    my $expected = "$runpath/tags.specified.calibrated.extracted";
-    $producer->add_stage(
-        products => [$expected],
-        build =>sub {
-            my @command = ('tagextract', '-f', 'EWI', $calibrated, $expected);
-            die 'Error executing: ' . join(SPACE, @command) . ": $!"
-              if system(@command);
-        });
-
-    # extract actual tags
-    my $extracted = "$runpath/tags.actual.parsed.sorted.extracted";
-    $producer->add_stage(
-        products => [$extracted],
-        build =>sub {
-            my @command = (
-                'tagextract', '-f', $testcase->{output_format},
-                $sorted, $extracted
-            );
-            die 'Error executing: ' . join(SPACE, @command) . ": $!"
-              if system(@command);
-        });
-
-    say EMPTY;
-    $producer->run(verbose => 1);
-
-    my @errors = check_result($testcase, $extracted, $expected);
+    my @errors;
+    if ($testcase->{match_strategy} eq 'literal') {
+        @errors = check_literal($testcase, $runpath, $output);
+    } elsif ($testcase->{match_strategy} eq 'tags') {
+        @errors = check_tags($testcase, $runpath, $output);
+    } else {
+        die "Unknown match strategy $testcase->{match_strategy}.";
+    }
 
     my $okay = !(scalar @errors);
 
     if($testcase->{todo} eq 'yes') {
       TODO: {
             local $TODO = 'Test marked as TODO.';
-            ok($okay, 'Lintian tags match for test marked TODO.');
+            ok($okay, 'Lintian passes for test marked TODO.');
         }
         return;
     }
 
-    ok($okay, "Lintian tags match for $testcase->{testname}");
+    ok($okay, "Lintian passes for $testcase->{testname}");
 
     diag $_ . NEWLINE for @errors;
 
-    #    for uncalibrated tests, use tags in spec path, for cut & paste
-    #      $expected = rel2abs("$testcase->{spec_path}/tags")
-    #      unless -e "$runpath/test_calibration";
-
-    unless($okay) {
-        my @command = ('tagdiff', $expected, $extracted);
-        my ($diff, $status) = capture_merged { system(@command); };
-        $status = ($status >> 8) & 255;
-        die 'Error executing: ' . join(SPACE, @command) . ": $!"
-          if $status;
-
-        if (length $diff) {
-            diag '--- ' . abs2rel($expected);
-            diag '+++ ' . abs2rel($extracted);
-            diag $diff;
-        }
-    }
-
     return;
 }
 
-=item check_result(DESC, ACTUAL, EXPECTED, ORIGINAL)
+sub check_literal {
+    my ($testcase, $runpath, $output) = @_;
+
+    # create expected output if it does not exist
+    my $expected = "$runpath/output";
+    path($expected)->touch
+      unless -e $expected;
+
+    my $raw = "$runpath/output.actual";
+    path($raw)->spew($output);
+
+    # run a sed-script if it exists
+    my $actual = "$runpath/output.actual.parsed";
+    my $script = "$runpath/post_test";
+    if(-f $script) {
+        sed_hook($script, $raw, $actual);
+    } else {
+        die"Could not copy actual tags $raw to $actual: $!"
+          if(system('cp', '-p', $raw, $actual));
+    }
+
+    # fail if output does not match
+    return 'Output does not match'
+      if (compare($expected, $actual) != 0);
+
+    return;
+}
+
+sub check_tags {
+    my ($testcase, $runpath, $output) = @_;
+
+    # create expected tags if there are none; helps when calibrating new tests
+    my $expected = "$runpath/tags";
+    path($expected)->touch
+      unless -e $expected;
+
+    my $raw = "$runpath/tags.actual";
+    path($raw)->spew($output);
+
+    # run a sed-script if it exists
+    my $actual = "$runpath/tags.actual.parsed";
+    my $sedscript = "$runpath/post_test";
+    if(-f $sedscript) {
+        sed_hook($sedscript, $raw, $actual);
+    } else {
+        die"Could not copy actual tags $raw to $actual: $!"
+          if(system('cp', '-p', $raw, $actual));
+    }
+
+    # calibrate tags; may write to $actual
+    my $calibrated = "$runpath/tags.specified.calibrated";
+    my $calscript = "$runpath/test_calibration";
+    if(-x $calscript) {
+        calibrate($calscript, $actual, $expected, $calibrated);
+    } else {
+        die"Could not copy expected tags $expected to $calibrated: $!"
+          if(system('cp', '-p', $expected, $calibrated));
+    }
+
+    say EMPTY;
+
+    return check_result($testcase, $runpath, $calibrated, $actual);
+}
+
+=item check_result(DESC, EXPECTED, ACTUAL)
 
 This routine checks if the EXPECTED tags match the calibrated ACTUAL for the
 test described by DESC. For some additional checks, also need the ORIGINAL
@@ -414,16 +378,38 @@ tags before calibration. Returns a list of errors, if there are any.
 =cut
 
 sub check_result {
-    my ($testcase, $actualpath, $expectedpath) = @_;
+    my ($testcase, $runpath, $expectedpath, $actualpath) = @_;
 
-    # fail if tags do not match
-    return 'Tags do not match' if (compare($actualpath, $expectedpath) != 0);
+    my @errors;
+
+    my @expectedlines
+      = reverse sort { order($a) cmp order($b) }(path($expectedpath)->lines);
+    my @actuallines
+      = reverse sort { order($a) cmp order($b) }(path($actualpath)->lines);
+
+    my $unsorted = diff(\@expectedlines, \@actuallines, { CONTEXT => 0 });
+    chomp $unsorted;
+
+    if(length $unsorted) {
+        my @lines = split(/\n/, $unsorted);
+        @lines = reverse sort @lines;
+
+        my $diff = EMPTY;
+        $diff .= $_ . NEWLINE for @lines;
+
+        path("$runpath/tagdiff")->spew($diff);
+
+        push(@errors, 'Tags do not match');
+        push(@errors, '--- ' . abs2rel($expectedpath));
+        push(@errors, diag '+++ ' . abs2rel($actualpath));
+        push(@errors, $diff);
+
+        return @errors;
+    }
 
     # no furter checks if the test is not about tags
     return unless length $testcase->{check};
 
-    my @errors;
-
     my $profile = Lintian::Profile->new(undef, [$ENV{LINTIAN_ROOT}]);
 
     # get tags for checks
@@ -480,3 +466,9 @@ sub check_result {
 =cut
 
 1;
+
+# Local Variables:
+# indent-tabs-mode: nil
+# cperl-indent-level: 4
+# End:
+# vim: syntax=perl sw=4 sts=4 sr et
